@@ -2,7 +2,7 @@ from pypiplot.pypiplot import pypiplot
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
 # module level doc-string
 __doc__ = """
@@ -32,6 +32,6 @@ Example
 
 References
 ----------
-https://github.com/erdogant/pypiplot
+* https://github.com/erdogant/pypiplot
 
 """
